package
Version:
v0.0.0-...-3adc4ee
Opens a new window with list of versions in this module.
Published: Dec 6, 2022
License: MIT
Opens a new window with license information.
Imports: 6
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Invalidate given tokens session
Returns true if a session is valid
type User struct {
ID uint `gorm:"primaryKey"`
Username string `json:"name"`
Email string `json:"email"`
Password string `json:"password"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.